==> nextcloud-21.0.0-9-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/privacy/l10n/zh_HK.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "隱私",
    "-" : "－",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "私隱權中心會向您顯示數據的存儲位置以及可以訪問這些數據的人 - 這些人是您分享了數據的人，或者是因為他們是管理員。",
    "Add external admin" : "新增外部管理員",
    "Name of external admin" : "外部管理員名字",
    "Your files are not protected by encryption." : "您的資料並未設定加密保護。",
    "Your data is located in: " : "您的數據位於：",
    "Please select a region" : "請選擇地區",
    "Somaliland" : "索馬里蘭",
    "Andorra" : "安道爾",
    "United Arab Emirates" : "阿拉伯聯合大公國",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布達",
    "Anguilla" : "安圭拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極地區",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳大利亞",
    "Aruba" : "阿路巴",
    "Åland Islands" : "奧蘭群島",
    "Azerbaijan" : "亞塞拜然",
    "Bosnia and Herzegovina" : "波希尼亞及赫塞哥維那",
    "Barbados" : "巴貝多",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "有吉納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "蒲隆地",
    "Benin" : "貝南",
    "Saint Barthélemy" : "聖巴泰勒米",
    "Bermuda" : "百慕達",
    "Brunei" : "汶萊",
    "Bolivia" : "玻利維亞",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯(基林)群島",
    "Democratic Republic of the Congo" : "剛果民主共和國",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "象牙海岸共和國",
    "Cook Islands" : "科克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國大陸",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角共和國",
    "Curaçao" : "庫拉索島",
    "Christmas Island" : "聖誕島領地",
    "Cyprus" : "塞浦路斯",
    "Czech" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麥",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多爾",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索匹亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands" : "福克蘭群島",
    "Micronesia" : "密克羅尼西亞",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "United Kingdom" : "英國",
    "Grenada" : "格林納達",
    "Georgia" : "格魯吉亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根息島",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "岡比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜德羅普",
    "Equatorial Guinea" : "赤道幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇",
    "Guatemala" : "危地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "圭亞那",
    "Honduras" : "洪都拉斯",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Croatia" : "克羅地亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "曼島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋屬地",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰島",
    "Italy" : "義大利",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯共和國",
    "Comores" : "科摩羅",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "North Korea" : "北韓",
    "South Korea" : "南韓",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Laos" : "老撾",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "利比里亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Moldova" : "摩爾多瓦",
    "Montenegro" : "黑山共和國",
    "Saint Martin" : "聖馬丁島(法屬)",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Macedonia" : "馬其頓",
    "Mali" : "馬里",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "毛里求斯",
    "Maldives" : "馬爾代夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫桑比克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日爾",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "尼日利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃島",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞新幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮埃爾和密克隆群島",
    "Pitcairn" : "皮特凱恩群島",
    "Puerto Rico" : "波多黎各",
    "Palestine" : "巴勒斯坦領土",
    "Portugal" : "葡萄牙",
    "Palau" : "帕勞",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔爾",
    "Réunion" : "留尼汪島",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russia" : "俄羅斯 ",
    "Rwanda" : "盧旺達",
    "Saudi Arabia" : "沙地阿拉伯",
    "Solomon Islands" : "所羅門群島",
    "Seychelles" : "塞舌爾群島",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿,亞森欣與垂斯坦昆哈",
    "Slovenia" : "斯洛文尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "San Marino" : "聖馬力諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬里",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美及普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten" : "聖馬丁(荷屬)",
    "Syria" : "敘利亞",
    "Swaziland" : "斯威士蘭",
    "Turks and Caicos Islands" : "特克斯及凱科斯群島",
    "Chad" : "乍得共和國",
    "Fr. S. Antarctic Lands" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克斯坦",
    "Tokelau" : "托克勞群島",
    "Timor-Leste" : "東帝汶",
    "Turkmenistan" : "土庫曼斯坦",
    "Tunisia" : "突尼斯",
    "Tonga" : "湯加王國",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "千里達及多巴哥",
    "Tuvalu" : "圖瓦盧",
    "Taiwan" : "台灣",
    "Tanzania" : "坦桑尼亞",
    "Ukraine" : "烏克蘭",
    "Uganda" : "烏干達",
    "United States Minor Outlying Islands" : "美國本土外小島嶼",
    "United States" : "美國",
    "Uruguay" : "烏拉圭",
    "Uzbekistan" : "烏茲別克",
    "Holy See" : "梵蒂岡",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Venezuela" : "委內瑞拉",
    "Virgin Islands (British)" : "英屬處女群島",
    "Virgin Islands (U.S.)" : "美屬處女群島",
    "Vietnam" : "越南",
    "Vanuatu" : "瓦努阿圖",
    "Wallis and Futuna" : "瓦利斯和富圖納",
    "Samoa" : "薩摩亞",
    "Yemen" : "也門",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Zambia" : "贊比亞",
    "Zimbabwe" : "津巴布韋",
    "Your Nextcloud account" : "您的Nextcloud帳號",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "你的資料就是你自己，在網路上很容易被濫用。Nextcloud團隊相信你有權決定你的資料如何被使用。Nextcloud會依照使用者資料宣言所述，捍衛你的權利。",
    "User Data Manifesto 2.0" : "用戶資料宣言 2.0",
    "Control" : "掌控",
    "over user data access" : "用戶資料存取 ",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "用戶明確和自願上傳的數據應在用戶的最終控制之下。 用戶應該能夠決定授予誰直接訪問其數據的權限，以及應該授予哪些權限和許可的訪問權限。",
    "Knowledge" : "知情",
    "of how the data is stored" : "知道數據如何存儲 ",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "將數據上載到特定服務提供商時，應告知用戶該特定服務提供商將數據存儲在何處，該特定服務提供商在多長時間內，在哪個管轄範圍內運營以及適用哪些法律。",
    "Freedom" : "自由",
    "to choose a platform" : "選擇平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "用戶應該能夠隨時從服務中提取其數據，而不會遭到供應商鎖定的情況。 開放標準格式和協議對於保證這一點是必要的。",
    "Learn more ↗" : "了解更多",
    "Where is your data?" : "您的數據在何方？",
    "Who has access to your data?" : "誰可以讀取您的數據？",
    "Administrators" : "管理員",
    "People you shared with" : "與您共享的人",
    "Privacy policy" : "私隱政策",
    "Read the privacy policy." : "閱覽私隱政策",
    "Encryption" : "加密"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.1-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/privacy/l10n/zh_HK.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "私隱",
    "-" : "－",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "私隱權中心會向您顯示數據的存儲位置以及可以存取這些數據的人 - 這些人是您分享了數據的人，或者是因為他們是管理員。",
    "Remove external admin" : "移除外部管理員",
    "Add external admin" : "新增外部管理員",
    "Name of external admin" : "外部管理員名字",
    "This server is using full-disk-encryption." : "該伺服器正在使用全盤加密。",
    "Your files are not protected by encryption." : "您的資料並未設定加密保護。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "您的檔案已通過 {linkopen} 伺服器端加密進行了加密↗{linkclose}。",
    "This server is protected with full-disk-encryption." : "該伺服器受全盤加密保護。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "您的檔案已通過 {linkopen} 伺服器端加密進行了加密↗{linkclose}。此外，此伺服器還受全磁盤加密保護。",
    "Your data is located in: " : "您的數據存儲於：",
    "The admin hasn't selected the location of the server yet." : "管理員尚未選擇伺服器所在的位置。",
    "Change data location" : "更改數據存儲位置",
    "Please select a region" : "請選擇地區",
    "You don't have any shares with individual users." : "您沒有與任何個人用戶的分享。",
    "Somaliland" : "索馬里蘭",
    "Andorra" : "安道爾",
    "United Arab Emirates" : "阿聯酋",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布達",
    "Anguilla" : "安圭拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳洲",
    "Aruba" : "阿路巴",
    "Åland Islands" : "奧蘭",
    "Azerbaijan" : "阿塞拜疆",
    "Bosnia and Herzegovina" : "波斯尼亞及黑塞哥維那",
    "Barbados" : "巴巴多斯",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "布基納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "布隆迪",
    "Benin" : "貝寧",
    "Saint Barthélemy" : "聖巴瑟米",
    "Bermuda" : "百慕達",
    "Brunei" : "汶萊",
    "Bolivia" : "玻利維亞",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯(基林)群島",
    "Democratic Republic of the Congo" : "剛果民主共和國",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "科特迪瓦",
    "Cook Islands" : "科克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國大陸",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角共和國",
    "Curaçao" : "庫拉索島",
    "Christmas Island" : "聖誕島領地",
    "Cyprus" : "塞浦路斯",
    "Czech" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麥",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多爾",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索匹亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands" : "福克蘭群島",
    "Micronesia" : "密克羅尼西亞",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "United Kingdom" : "英國",
    "Grenada" : "格林納達",
    "Georgia" : "格魯吉亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根息島",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "岡比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜德羅普",
    "Equatorial Guinea" : "赤道幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇",
    "Guatemala" : "危地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "圭亞那",
    "Honduras" : "洪都拉斯",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Croatia" : "克羅地亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "萌島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋領地",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰島",
    "Italy" : "意大利",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯共和國",
    "Comores" : "科摩羅",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "North Korea" : "北韓",
    "South Korea" : "南韓",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Laos" : "老撾",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "利比里亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Moldova" : "摩爾多瓦",
    "Montenegro" : "黑山",
    "Saint Martin" : "法屬聖馬丁島",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Macedonia" : "馬其頓",
    "Mali" : "馬里",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "毛里求斯",
    "Maldives" : "馬爾代夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫桑比克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日爾",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "尼日利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃島",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞新幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮埃爾和密克隆群島",
    "Pitcairn" : "皮特凱恩群島",
    "Puerto Rico" : "波多黎各",
    "Palestine" : "巴勒斯坦領土",
    "Portugal" : "葡萄牙",
    "Palau" : "帕勞",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔爾",
    "Réunion" : "留尼汪島",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russia" : "俄羅斯 ",
    "Rwanda" : "盧旺達",
    "Saudi Arabia" : "沙地阿拉伯",
    "Solomon Islands" : "所羅門群島",
    "Seychelles" : "塞舌爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿，亞森欣與垂斯坦昆哈",
    "Slovenia" : "斯洛文尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "San Marino" : "聖馬力諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬里",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美及普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten" : "聖馬丁(荷屬)",
    "Syria" : "敘利亞",
    "Swaziland" : "斯威士蘭",
    "Turks and Caicos Islands" : "特克斯及凱科斯群島",
    "Chad" : "乍得共和國",
    "Fr. S. Antarctic Lands" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克斯坦",
    "Tokelau" : "托克勞群島",
    "Timor-Leste" : "東帝汶",
    "Turkmenistan" : "土庫曼斯坦",
    "Tunisia" : "突尼斯",
    "Tonga" : "湯加王國",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "千里達及多巴哥",
    "Tuvalu" : "圖瓦盧",
    "Taiwan" : "台灣",
    "Tanzania" : "坦桑尼亞",
    "Ukraine" : "烏克蘭",
    "Uganda" : "烏干達",
    "United States Minor Outlying Islands" : "美國本土外小島嶼",
    "United States" : "美國",
    "Uruguay" : "烏拉圭",
    "Uzbekistan" : "烏茲別克",
    "Holy See" : "梵蒂岡",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Venezuela" : "委內瑞拉",
    "Virgin Islands (British)" : "英屬處女群島",
    "Virgin Islands (U.S.)" : "美屬處女群島",
    "Vietnam" : "越南",
    "Vanuatu" : "瓦努阿圖",
    "Wallis and Futuna" : "瓦利斯和富圖納",
    "Samoa" : "薩摩亞",
    "Yemen" : "也門",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Zambia" : "贊比亞",
    "Zimbabwe" : "津巴布韋",
    "Your Nextcloud account" : "您的Nextcloud帳號",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "您的數據代表您的身份，可以很容易地被濫用。 Nextcloud 團隊相信您有權決定如何處理你的數據。Nextcloud 會依照用戶資料宣言所述，捍衛你的權利！",
    "User Data Manifesto 2.0" : "用戶資料宣言 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "定義互聯網時代用户控制自己數據的基本權利",
    "Control" : "掌控",
    "over user data access" : "用戶資料存取 ",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "用戶明確和自願上傳的數據應在用戶的最終控制之下。 用戶應該能夠決定授予誰直接存取其數據的權限，以及應該授予哪些權限和許可的存取權限。",
    "Knowledge" : "知情",
    "of how the data is stored" : "知道數據如何存儲 ",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "將數據上載到特定服務提供商時，應告知用戶該特定服務提供商將數據存儲在何處，該特定服務提供商在多長時間內，在哪個管轄範圍內運營以及適用哪些法律。",
    "Freedom" : "自由",
    "to choose a platform" : "選擇平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "用戶應該能夠隨時從服務中提取其數據，而不會遭到供應商鎖定的情況。 開放標準格式和協議對於保證這一點是必要的。",
    "Learn more ↗" : "了解更多",
    "Where is your data?" : "您的數據在何方？",
    "Who has access to your data?" : "誰可以讀取您的數據？",
    "Administrators" : "管理員",
    "People you shared with" : "與您共享的人",
    "Privacy policy" : "私隱政策",
    "Read the privacy policy." : "閱覽私隱政策。",
    "Encryption" : "加密"
},
"nplurals=1; plural=0;");
